.. testsetup:: *

   from pwnlib.runner import *
   from pwnlib.asm import asm

:mod:`pwnlib.runner` --- Running Shellcode
===========================================

.. automodule:: pwnlib.runner
   :members:
